package de.intevation.aft;

import java.util.Map;
import java.util.HashMap;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;
import org.w3c.dom.NodeList;
import org.w3c.dom.Element;

import de.intevation.db.ConnectedStatements;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class River
extends      IdPair
{
    private static Logger log = Logger.getLogger(River.class);

    public static final Pattern NUMBER = Pattern.compile("0*([0-9]+)");

    protected String name;

    public River() {
    }

    public River(int id1, int id2, String name) {
        super(id1, id2);
        this.name = name;
    }

    public String getName() {
        return name;
    }

    public static Long numberToLong(String s) {
        Matcher m = NUMBER.matcher(s);
        if (!m.matches()) return null;
        String ns = m.group(1);
        return Long.valueOf(ns.length() == 0 ? "0": ns);
    }

    public static Map<Long, DIPSGauge> indexByNumber(Document document) {
        Map<Long, DIPSGauge> map = new HashMap<Long, DIPSGauge>();
        NodeList nodes = document.getElementsByTagName("PEGELSTATION");
        for (int i = nodes.getLength()-1; i >= 0; --i) {
            Element element = (Element)nodes.item(i);
            Long number = numberToLong(element.getAttribute("NUMMER"));
            if (number != null) {
                map.put(number, new DIPSGauge(element));
            }
        }
        return map;
    }

    public void sync(SyncContext context) throws SQLException {
        log.info("sync river: " + this);

        ConnectedStatements flysStatements = context.getFlysStatements();
        ConnectedStatements aftStatements  = context.getAftStatements();

        ResultSet messstellenRs = aftStatements
            .getStatement("select.messstelle")
            .clearParameters()
            .setInt("GEWAESSER_NR", id2).executeQuery();

        while (messstellenRs.next()) {
            String name = messstellenRs.getString("NAME");
            String num  = messstellenRs.getString("MESSSTELLE_NR");
            System.err.println(name + ": " + num);
        }

        messstellenRs.close();

        ResultSet gaugesRs = flysStatements
            .getStatement("select.gauges")
            .clearParameters()
            .setInt("river_id", id1).executeQuery();

        while (gaugesRs.next()) {
            int gaugeId = gaugesRs.getInt("id");
            String name = gaugesRs.getString("name");
            System.err.println(name + ": " + gaugeId);
        }

        gaugesRs.close();

        Map<Long, DIPSGauge> map = indexByNumber(context.getDips());
    }

    public String toString() {
        return "[River: name=" + name + ", " + super.toString() + "]";
    }

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
